import { AppConfigure } from './AppConfigure';
import { IContainer, LoadType } from '@ts-ioc/core';
import { IApplicationBuilder, CustomRegister } from './IApplicationBuilder';
import { ModuleBuilder } from './ModuleBuilder';
import { AnyModuleBuilder } from './IModuleBuilder';
/**
 * application builder.
 *
 * @export
 * @class Default ApplicationBuilder
 * @extends {ModuleBuilder}
 * @template T
 */
export declare class DefaultApplicationBuilder<T> extends ModuleBuilder<T> implements IApplicationBuilder<T> {
    baseURL?: string;
    protected globalConfig: Promise<AppConfigure>;
    protected globalModules: LoadType[];
    protected customRegs: CustomRegister<T>[];
    root: IContainer;
    constructor(baseURL?: string);
    static create(baseURL?: string): AnyModuleBuilder;
    /**
     * use configuration.
     *
     * @param {(string | AppConfigure)} [config]
     * @returns {this} global config for this application.
     * @memberof Bootstrap
     */
    useConfiguration(config?: string | AppConfigure, container?: IContainer): this;
    /**
     * use module as global Depdences module.
     *
     * @param {...LoadType[]} modules
     * @returns {this}
     * @memberof PlatformServer
     */
    use(...modules: LoadType[]): this;
    registerConfgureDepds(container: IContainer, config: AppConfigure): Promise<AppConfigure>;
    protected mergeGlobalConfig(globalCfg: AppConfigure, moduleCfg: AppConfigure): AppConfigure;
    protected regDefaultContainer(): IContainer;
    /**
     * register ioc exts
     *
     * @protected
     * @param {IContainer} container
     * @param {AppConfigure} config
     * @returns {Promise<IContainer>}
     * @memberof ApplicationBuilder
     */
    protected registerExts(container: IContainer, config: AppConfigure): Promise<IContainer>;
    protected bindAppConfig(config: AppConfigure): AppConfigure;
    protected getDefaultConfig(): AppConfigure;
    static classAnnations: any;
}
