"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var IBootBuilder_1 = require("./IBootBuilder");
var core_1 = require("@ts-ioc/core");
/**
 * token bootstrap builder. build class with metadata and config.
 *
 * @export
 * @class BootBuilder
 * @implements {implements IBootBuilder<T>}
 * @template T
 */
var BootBuilder = /** @class */ (function () {
    // /**
    //  * ioc container.
    //  *
    //  * @type {IContainer}
    //  * @memberof BootBuilder
    //  */
    // @Inject(ContainerToken)
    // container: IContainer;
    function BootBuilder(container) {
        this.container = container;
    }
    BootBuilder_1 = BootBuilder;
    BootBuilder.prototype.build = function (token, config, data) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var instance;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.createInstance(token, data)];
                    case 1:
                        instance = _a.sent();
                        return [4 /*yield*/, this.buildStrategy(instance, config)];
                    case 2:
                        instance = _a.sent();
                        return [2 /*return*/, instance];
                }
            });
        });
    };
    BootBuilder.prototype.buildByConfig = function (config, data) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var token;
            return tslib_1.__generator(this, function (_a) {
                if (core_1.isToken(config)) {
                    return [2 /*return*/, this.build(config, null, data)];
                }
                else {
                    token = this.getBootstrapToken(config);
                    return [2 /*return*/, this.build(token, config, data)];
                }
                return [2 /*return*/];
            });
        });
    };
    BootBuilder.prototype.createInstance = function (token, config, data) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var instance;
            return tslib_1.__generator(this, function (_a) {
                if (!token) {
                    throw new Error('cant not find bootstrap token.');
                }
                if (!this.container.has(token)) {
                    if (core_1.isClass(token)) {
                        this.container.register(token);
                    }
                    else {
                        throw new Error("cant not find token " + token.toString() + " in container.");
                    }
                }
                instance = this.resolveToken(token, data);
                return [2 /*return*/, instance];
            });
        });
    };
    /**
     * bundle instance via config.
     *
     * @param {T} instance
     * @param {ModuleConfigure} config
     * @param {IContainer} [container]
     * @returns {Promise<T>}
     * @memberof BootBuilder
     */
    BootBuilder.prototype.buildStrategy = function (instance, config) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, instance];
            });
        });
    };
    BootBuilder.prototype.getBootstrapToken = function (config) {
        return config.bootstrap;
    };
    BootBuilder.prototype.resolveToken = function (token, data) {
        return this.container.resolve(token, data);
    };
    BootBuilder.prototype.getBuilderViaConfig = function (builder, container) {
        if (core_1.isToken(builder)) {
            return container.resolve(builder);
        }
        else if (builder instanceof BootBuilder_1) {
            return builder;
        }
        return null;
    };
    var BootBuilder_1;
    BootBuilder.classAnnations = { "name": "BootBuilder", "params": { "constructor": ["container"], "build": ["token", "config", "data"], "buildByConfig": ["config", "data"], "createInstance": ["token", "config", "data"], "buildStrategy": ["instance", "config"], "getBootstrapToken": ["config"], "resolveToken": ["token", "data"], "getBuilderViaConfig": ["builder", "container"] } };
    BootBuilder = BootBuilder_1 = tslib_1.__decorate([
        core_1.Singleton(IBootBuilder_1.BootBuilderToken),
        tslib_1.__param(0, core_1.Inject(core_1.ContainerToken)),
        tslib_1.__metadata("design:paramtypes", [Object])
    ], BootBuilder);
    return BootBuilder;
}());
exports.BootBuilder = BootBuilder;

//# sourceMappingURL=sourcemaps/BootBuilder.js.map
