import { IContainer, Token, Type, Providers, IContainerBuilder, Registration } from '@ts-ioc/core';
import { IModuleBuilder } from './IModuleBuilder';
import { ModuleConfigure, ModuleConfig } from './ModuleConfigure';
import { LoadedModule } from './ModuleType';
import { IBootBuilder, AnyBootstrapBuilder } from './IBootBuilder';
import { ContainerPool } from './ContainerPool';
export declare class InjectModuleLoadToken<T> extends Registration<T> {
    constructor(token: Token<T>);
    static classAnnations: any;
}
/**
 * module builder
 *
 * @export
 * @class ModuleBuilder
 * @implements {IModuleBuilder}
 * @template T
 */
export declare class ModuleBuilder<T> implements IModuleBuilder<T> {
    constructor();
    protected pools: any;
    getPools(): ContainerPool;
    setPools(pools: ContainerPool): void;
    protected regDefaultContainer(): IContainer;
    /**
     * get container of the module.
     *
     * @param {(ModuleType | ModuleConfigure)} token module type or module configuration.
     * @param {IContainer} [defaultContainer] set default container or not. not set will create new container.
     * @param {IContainer} [parent] set the container parent, default will set root default container.
     * @returns {IContainer}
     * @memberof ModuleBuilder
     */
    getContainer(token: Token<T> | ModuleConfigure, defaultContainer?: IContainer, parent?: IContainer): IContainer;
    protected setParent(container: IContainer, parent?: IContainer): void;
    createContainer(): IContainer;
    protected containerBuilder: IContainerBuilder;
    getContainerBuilder(): IContainerBuilder;
    protected createContainerBuilder(): IContainerBuilder;
    load(token: Token<T> | ModuleConfigure, defaultContainer?: IContainer, parent?: IContainer): Promise<LoadedModule>;
    /**
     * build module.
     *
     * @param {(Token<T> | ModuleConfig<T>)} token
     * @param {(IContainer | LoadedModule)} [defaults]
     * @returns {Promise<T>}
     * @memberof ModuleBuilder
     */
    build(token: Token<T> | ModuleConfig<T>, defaults?: IContainer | LoadedModule): Promise<T>;
    /**
    * bootstrap module's main.
    *
    * @param {(Token<T> | ModuleConfig<T>)} token
    * @param {*} [data]
    * @param {IContainer} [defaultContainer]
    * @returns {Promise<MdlInstance<T>>}
    * @memberof ModuleBuilder
    */
    bootstrap(token: Token<T> | ModuleConfig<T>, data?: any, defaultContainer?: IContainer): Promise<any>;
    protected getBuilder(container: IContainer, cfg: ModuleConfigure): IModuleBuilder<T>;
    protected getBootstrapBuilder(container: IContainer, bootBuilder: Token<IBootBuilder<any>> | IBootBuilder<any>): AnyBootstrapBuilder;
    protected getDefaultBootBuilder(container: IContainer): IBootBuilder<any>;
    importModule(token: Token<T> | ModuleConfigure, container: IContainer): Promise<IContainer>;
    getDecorator(): string;
    /**
     * get configuration.
     *
     * @returns {ModuleConfigure}
     * @memberof ModuleBuilder
     */
    getConfigure(token?: Token<T> | ModuleConfigure, container?: IContainer): ModuleConfigure;
    registerDepdences(container: IContainer, config: ModuleConfigure): Promise<ModuleConfigure>;
    protected getBootstrapToken(cfg: ModuleConfigure): Token<T>;
    protected importConfigExports(container: IContainer, providerContainer: IContainer, cfg: ModuleConfigure): Promise<IContainer>;
    protected registerConfgureDepds(container: IContainer, config: ModuleConfigure): Promise<ModuleConfigure>;
    protected getMetaConfig(bootModule: Type<any>): ModuleConfigure;
    protected isIocExt(token: Type<any>): boolean;
    protected isDIModule(token: Token<any>): boolean;
    protected registerExts(container: IContainer, config: ModuleConfigure): Promise<IContainer>;
    protected bindProvider(container: IContainer, providers: Providers[]): Token<any>[];
    static classAnnations: any;
}
